@@ -388,6 +388,14 @@ from .snappi_convergence import ConvergenceState
 from .snappi_convergence import TransmitState
 from .snappi_convergence import LinkState
 from .snappi_convergence import RouteState
+from .snappi_convergence import PingRequest
+from .snappi_convergence import Ping
+from .snappi_convergence import PingIpv4
+from .snappi_convergence import PingIpv6
+from .snappi_convergence import PingIter
+from .snappi_convergence import PingResponse
+from .snappi_convergence import Response
+from .snappi_convergence import ResponseIter
 from .snappi_convergence import ConvergenceRequest
 from .snappi_convergence import FlowMetricsRequest
 from .snappi_convergence import FlowMetricGroupRequest
